#
#  FILE NAME:
#      class_renamed.py
#
#  AUTHOR(S):
#      Dariusz Walczak <dariusz.walczak@gmail.com>
#

# Standard library imports:
import logging
import warnings


_LOG = logging.getLogger( "p3.base" )


class ClassRenamed( object ):
    def __init__( self, src_class_name, dst_class ):
        self.src_cls_name = src_class_name
        self.dst_cls     = dst_class

    def _issue_warning( self ):
        msg = ("The '{0:s}' class was renamed to '{1:s}'. '{0:s}' is currently an alias and will"
               " be removed in one of future releases."
               "".format( self.src_cls_name, self.dst_cls.__name__ ))
        _LOG.warning( msg )
        warnings.warn( msg, DeprecationWarning, 3 )

    def __call__( self, *args, **kwargs ):
        self._issue_warning()

        return self.dst_cls( *args, **kwargs )

    def __getattr__( self, attr ):
        self._issue_warning()
        return getattr( self.dst_cls, attr )
