#
#  FILE NAME:
#      handler.py
#
#  AUTHOR(S):
#      Dariusz Walczak <dariusz.walczak@gmail.com>
#

from p3.base import challenge_module

# Standard library imports:
import logging

# Third party imports:
challenge_module('django')
import django.http
import django.template.loader

# P3 imports:
from p3.base.import_helpers import import_object
from p3.logic.response import PageResponse, RedirectResponse


_LOG = logging.getLogger( "p3.web" )


def serve_django_page( request, logic ):
    _LOG.info( "Serving page generated by '%s' class", logic )
    
    cls = import_object( logic )
    obj = cls( request )
    obj.execute()

    if isinstance( obj.response, PageResponse ):
        rendered = django.template.loader.render_to_string(
            obj.response.template_name, obj.response.template_context )

        return django.http.HttpResponse( rendered, 200, content_type='text/html' )
    elif isinstance( obj.response, RedirectResponse ):
        return django.http.HttpResponseRedirect( obj.response.url )
    else:
        assert False
